@@ -13,7 +13,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from metricbase import MetricBase
+from monascastatsd.metricbase import MetricBase
 
 
 class Counter(MetricBase):
